@@ -10,10 +10,10 @@
 #undef HAVE_SOCKET
 #undef HAVE_STRUCT_LINGER
 #undef HAVE_NSL
-#undef USING_OAF
-#undef HAVE_GCONF
 #undef HAVE_OLDER_BZIP2
 #undef GNOME_PLATFORM_VERSION
 #undef ENABLE_PROFILER
 #undef HAVE_OPENSSL
-#undef USE_LIBICONV
+#undef HAVE_FAM
+#undef GETTEXT_PACKAGE
+
